@@ -11,12 +11,10 @@ use strict;
 use warnings;
 use 5.010;
 package Dist::Zilla::App::Command::authordebs;
-$Dist::Zilla::App::Command::authordebs::VERSION = '0.004';
+$Dist::Zilla::App::Command::authordebs::VERSION = '0.005';
 use Debian::AptContents;
 use DhMakePerl::Utils qw(is_core_module);
 use Dist::Zilla::Util::AuthorDeps;
-use Config::Model::Dpkg;
-use Config::Model qw/cme/;
 
 use Dist::Zilla::App -command;
 
@@ -26,7 +24,6 @@ sub opt_spec {
     return (
         [ 'missing', 'list only the missing dependencies' ],
         [ 'install', 'also run sudo apt-get install for missing packages' ],
-        [ 'update-control|uc', 'Update debian/control file' ],
         [ 'verbose', 'show more information on dependency modules'],
     );
 }
@@ -71,27 +68,11 @@ EOF
         }
     }
 
-    if ($opt->{update_control}) {
-        warn "updating control file...";
-
-        # add Debian style dependencies
-        for my $p (qw/dh-dist-zilla dh-sequence-dist-zilla/) { $pkgs{$p} = 1;}
-
-        # remove package implied by dh-sequence-dist-zilla
-        delete $pkgs{'libdist-zilla-perl'};
-
-        # remove git plugin as it cannot be used in Debian build systems
-        delete $pkgs{'libdist-zilla-plugin-git-perl'};
-
-        my $pkgs = join( ",", sort keys %pkgs );
-        cme('dpkg-control')->modify("source Build-Depends:.ensure($pkgs)");
-    }
-
     if ($opt->{install} and %pkgs) {
         warn "Installing required packages...\n";
         system(qw/sudo apt-get install/, sort keys %pkgs);
     }
-    elsif (not $opt->{update_control}) {
+    else {
         say join("\n",sort keys %pkgs);
     }
 }
@@ -108,7 +89,7 @@ Dist::Zilla::App::Command::authordebs - List or install Dist::Zilla authors depe
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -135,11 +116,6 @@ Only the missing modules are listed.
 Install required packages with C<sudo apt-get install>, so you must
 have sudo configured properly.
 
-=item --update-control or --uc
-
-Update the "Build-Depends" field of C<debian/control> file with the
-required packages.
-
 =back
 
 =head1 EXIT CODE
